# Conductor plugin for Unreal

Unreal Engine plugin to manage MovieRenderPipeline submissions to Conductor's cloud service. 

Supported software: Unreal Engine 5 and higher


## Development

See [DEVELOPMENT](DEVELOPMENT.md) for more information.
